==> tallipoika-2024.1.3.tar.gz: tallipoika-2024.1.3/README.md <==
# Tallipoika

Stableson (Finnish: tallipoika) - a JSON Canonicalization Scheme (JCS) implementation.

[![License](https://git.sr.ht/~sthagen/tallipoika/blob/default/docs/badges/license-spdx-mit.svg)](https://git.sr.ht/~sthagen/tallipoika/tree/default/item/LICENSE)
[![Country of Origin](https://git.sr.ht/~sthagen/tallipoika/blob/default/docs/badges/country-of-origin-name-switzerland-neutral.svg)](https://git.sr.ht/~sthagen/tallipoika/tree/default/item/COUNTRY-OF-ORIGIN)
[![Export Classification Control Number (ECCN)](https://git.sr.ht/~sthagen/tallipoika/blob/default/docs/badges/export-control-classification-number_eccn-ear99-neutral.svg)](https://git.sr.ht/~sthagen/tallipoika/tree/default/item/EXPORT-CONTROL-CLASSIFICATION-NUMBER)
[![Configuration](https://git.sr.ht/~sthagen/tallipoika/blob/default/docs/badges/configuration-sbom.svg)](https://git.sr.ht/~sthagen/tallipoika/tree/default/item/docs/third-party/README.md)

[![Version](https://git.sr.ht/~sthagen/tallipoika/blob/default/docs/badges/latest-release.svg)](https://pypi.python.org/pypi/tallipoika/)
[![Downloads](https://git.sr.ht/~sthagen/tallipoika/blob/default/docs/badges/downloads-per-month.svg)](https://pepy.tech/project/tallipoika)
[![Python](https://git.sr.ht/~sthagen/tallipoika/blob/default/docs/badges/python-versions.svg)](https://pypi.python.org/pypi/tallipoika/)
[![Maintenance Status](https://git.sr.ht/~sthagen/tallipoika/blob/default/docs/badges/commits-per-year.svg)](https://git.sr.ht/~sthagen/tallipoika/log)

## Documentation

User and developer [documentation of tallipoika](https://codes.dilettant.life/docs/tallipoika).

## Bug Tracker

Any feature requests or bug reports shall go to the [todos of tallipoika](https://todo.sr.ht/~sthagen/tallipoika).

## Primary Source repository

The main source of `tallipoika` is on a mountain in central Switzerland.
We use distributed version control (git).
There is no central hub.
Every clone can become a new source for the benefit of all.
The preferred public clone of `tallipoika` is:

* [at sourcehut](https://git.sr.ht/~sthagen/tallipoika) - a collection of tools useful for software development.

## Contributions

Please do not submit "pull requests" (I found no way to disable that "feature" on GitHub).
If you like to share small changes under the repositories license please kindly do so by sending a patchset.
You can either send such a patchset per email using [git send-email](https://git-send-email.io) or
if you are a sourcehut user by selecting "Prepare a patchset" on the summary page of your fork at [sourcehut](https://git.sr.ht/).

## Support

Please kindly submit issues at https://todo.sr.ht/~sthagen/tallipoika or write plain text email to ~sthagen/tallipoika@lists.sr.ht to submit patches and request support. Thanks.

## Thanks also to

This implementation is based on the [original implementation of the JSON Canonicalization Scheme (JCS)](https://github.com/cyberphone/json-canonicalization) gently provided under the APACHE-2.0 license by Anders Rundgren.
The initial implementation of `tallipoika` is kept similar to show the identical functioning of both implementation.
Also, the input and output JSON tests are provided within this repository as a service for validators.

# Status

Experimental.

**Note**: The default branch is `default`.

==> tallipoika-2024.1.6.tar.gz: tallipoika-2024.1.6/README.md <==
# Tallipoika

Stableson (Finnish: tallipoika) - a JSON Canonicalization Scheme (JCS) implementation.

[![License](https://git.sr.ht/~sthagen/tallipoika/blob/default/docs/badges/license-spdx-mit.svg)](https://git.sr.ht/~sthagen/tallipoika/tree/default/item/LICENSE)
[![Country of Origin](https://git.sr.ht/~sthagen/tallipoika/blob/default/docs/badges/country-of-origin-name-switzerland-neutral.svg)](https://git.sr.ht/~sthagen/tallipoika/tree/default/item/COUNTRY-OF-ORIGIN)
[![Export Classification Control Number (ECCN)](https://git.sr.ht/~sthagen/tallipoika/blob/default/docs/badges/export-control-classification-number_eccn-ear99-neutral.svg)](https://git.sr.ht/~sthagen/tallipoika/tree/default/item/EXPORT-CONTROL-CLASSIFICATION-NUMBER)
[![Configuration](https://git.sr.ht/~sthagen/tallipoika/blob/default/docs/badges/configuration-sbom.svg)](https://git.sr.ht/~sthagen/tallipoika/tree/default/item/docs/third-party/README.md)

[![Version](https://git.sr.ht/~sthagen/tallipoika/blob/default/docs/badges/latest-release.svg)](https://pypi.python.org/pypi/tallipoika/)
[![Downloads](https://git.sr.ht/~sthagen/tallipoika/blob/default/docs/badges/downloads-per-month.svg)](https://pepy.tech/project/tallipoika)
[![Python](https://git.sr.ht/~sthagen/tallipoika/blob/default/docs/badges/python-versions.svg)](https://pypi.python.org/pypi/tallipoika/)
[![Maintenance Status](https://git.sr.ht/~sthagen/tallipoika/blob/default/docs/badges/commits-per-year.svg)](https://git.sr.ht/~sthagen/tallipoika/log)

## Documentation

User and developer [documentation of tallipoika](https://codes.dilettant.life/docs/tallipoika).

## Bug Tracker

Any feature requests or bug reports shall go to the [todos of tallipoika](https://todo.sr.ht/~sthagen/tallipoika).

## Primary Source repository

The main source of `tallipoika` is on a mountain in central Switzerland.
We use distributed version control (git).
There is no central hub.
Every clone can become a new source for the benefit of all.
The preferred public clone of `tallipoika` is:

* [at sourcehut](https://git.sr.ht/~sthagen/tallipoika) - a collection of tools useful for software development.

## Contributions

Please do not submit "pull requests" (I found no way to disable that "feature" on GitHub).
If you like to share small changes under the repositories license please kindly do so by sending a patchset.
You can either send such a patchset per email using [git send-email](https://git-send-email.io) or
if you are a sourcehut user by selecting "Prepare a patchset" on the summary page of your fork at [sourcehut](https://git.sr.ht/).

## Support

Please kindly submit issues at https://todo.sr.ht/~sthagen/tallipoika or write plain text email to ~sthagen/tallipoika@lists.sr.ht to submit patches and request support. Thanks.

## Thanks also to

This implementation is based on the [original implementation of the JSON Canonicalization Scheme (JCS)](https://github.com/cyberphone/json-canonicalization) gently provided under the APACHE-2.0 license by Anders Rundgren.
The initial implementation of `tallipoika` was kept similar to show the identical functioning of both implementations.
Also, the input and output JSON tests are provided within this repository as a service for validators and to help tracing the evolution in context.

# Status

Experimental.

**Note**: The default branch is `default`.
